==> jboss-ewp-src-5.1.2.zip: org/picketlink/identity/federation/web/interfaces/IRoleValidator.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors. 
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.picketlink.identity.federation.web.interfaces;

import java.security.Principal;
import java.util.List;
import java.util.Map;

/**
 * Validate the passed Roles
 * @author Anil.Saldhana@redhat.com
 * @since Aug 21, 2009
 */
public interface IRoleValidator
{
   /**
    * Initialize the validator
    * @param options
    */
   void intialize(Map<String,String> options);
   
   /**
    * Validate whether the principal with the given
    * list of roles is valid
    * @param userPrincipal
    * @param roles
    * @return
    */
   boolean userInRole(Principal userPrincipal, List<String> roles); 
}

==> jboss-ewp-src-5.2.0.zip: org/picketlink/identity/federation/web/interfaces/IRoleValidator.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.picketlink.identity.federation.web.interfaces;

import java.security.Principal;
import java.util.List;
import java.util.Map;

/**
 * Validate the passed Roles
 *
 * @author Anil.Saldhana@redhat.com
 * @since Aug 21, 2009
 */
public interface IRoleValidator {
    /**
     * Initialize the validator
     *
     * @param options
     */
    void intialize(Map<String, String> options);

    /**
     * Validate whether the principal with the given list of roles is valid
     *
     * @param userPrincipal
     * @param roles
     * @return
     */
    boolean userInRole(Principal userPrincipal, List<String> roles);
}
